@@ -67,6 +67,18 @@ def generic_init(dir, helper_library_path, mldock_config, testing_framework, ser
         logger.info("Adding {} service".format(service))
         _copy_boilerplate_to_dst(os.path.join(template_dir,'service',service), service_directory)
 
+def _make_sagemaker_input_data_configs(data_channels: list):
+    """restructures a list of data names as sagemaker input data configs"""
+    return {name: {} for name in data_channels}
+
+def _extract_data_channels_from_mldock(mldock_data: list):
+
+    data_channels = [
+        data_config['channel'] for data_config in mldock_data
+    ]
+
+    return _make_sagemaker_input_data_configs(data_channels=data_channels)
+
 def sagemaker_init(dir, helper_library_path, mldock_config, no_prompt, testing_framework, service):
 
     logger.info("Initializing Assets - Sagemaker Container")
@@ -120,5 +132,9 @@ def sagemaker_init(dir, helper_library_path, mldock_config, no_prompt, testing_f
 
     logger.info("Adding dummy sagemaker goodies")
     _write_json({}, Path(dir,'config/hyperparameters.json'))
-    _write_json({}, Path(dir,'config/inputdataconfig.json'))
-    _write_json({}, Path(dir,'config/resourceconfig.json'))
+
+    # get list of dataset names
+    mldock_data = mldock_config.get("data", None)
+    input_config_config = _extract_data_channels_from_mldock(mldock_data)
+    _write_json(input_config_config, Path(dir,'config/inputdataconfig.json'))
+    _write_json({"current_host": "dummy_host", "hosts": ["dummy_host", "second_dummy_host"]}, Path(dir,'config/resourceconfig.json'))
